import 'package:flutter_webrtc/flutter_webrtc.dart';
import 'package:transmedika_one_to_one_call/webrtc/one_to_one/models/consultation.dart';
import 'package:transmedika_one_to_one_call/webrtc/one_to_one/models/registration_session.dart';

import '../../../models/response/socket_response.dart';
import '../../../usecase/socket_usecase_service.dart';

abstract class OneToOneUseCaseService extends SocketUseCaseService{
  Future<void> stop();
  Future<void> register({required String from, required String to, required bool isCalling});
  Future<void> publishCallVideo({required RegistrationSession from, required RegistrationSession to,
    required RTCSessionDescription sessionDescription
  });
  Future<void> publishIncomingCallVideo({
    required RegistrationSession to,
    required RTCSessionDescription sessionDescription,
    Consultation? consultation
  });
  RTCPeerConnection? getPeerConnection();
  Future<void> createLocalPeerConnection({
    required Function(MediaStream stream) onLocalStream,
    required Function(MediaStream stream) onAddRemoteStream,
    required Function(MediaStream stream)? onRemoveRemoteStream
  });
  Future<MediaStream> createStream();
  Future<void> createOffer({
    required RegistrationSession from,
    required RegistrationSession to,
    required bool isCalling,
    Consultation? consultation
  });
  Future<void> iceCandidate(SocketResponse response);
  Future<void> receiveVideoAnswer(SocketResponse response);
  Future<void> onIceCandidate(RTCIceCandidate rtcIceCandidate);
  Future<void> closeSession();
  Future<void> notifyCaller({required RegistrationSession from, required String to});
  Future<void> reject({required RegistrationSession from, required RegistrationSession to});
  void muteMic();
  void enableVideo();
  void switchCamera();
}